# LoIpGen

This is a simple package to generate Lorem Ipsum text with as many characters as you want

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install LoIpGen

```bash
pip install LoIpGen
```

## Usage

```python
from LoIpGen.LoIpGen import generate_lorem
print(generate_lorem(100))
```

## Author
NoemyT

## License
[MIT](https://choosealicense.com/licenses/mit/)